pub struct ReceiptBurned {
pub token: Address,
pub receiver: Address,
pub blockedNonce: u64,
pub blockedAt: u64,
pub receiptVersion: u8,
pub originator: Address,
pub recipient: Address,
pub recoveryAuthority: Address,
pub caller: Address,
pub amount: Uint<256, 4>,
}Expand description
@notice Emitted when blocked funds are burned with a valid receipt.
@param token TIP-20 token burned by the guard.
@param receiver Resolved account where funds would settle; for virtual recipients its their master.
@param blockedNonce Guard nonce from the burned receipt.
@param blockedAt Block timestamp from the burned receipt.
@param receiptVersion Claim receipt layout version.
@param originator Original sender/originator from the burned receipt.
@param recipient Addressed recipient from the burned receipt; may be virtual.
@param recoveryAuthority Claim authority from the burned receipt.
@param caller Account that submitted the burn.
@param amount Amount of funds burned.
Event with signature ReceiptBurned(address,address,uint64,uint64,uint8,address,address,address,address,uint256) and selector 0x61d14663748cd685c80a8434fc260ea4f4b27e213768b94375aa33b3985bf952.
event ReceiptBurned(address indexed token, address indexed receiver, uint64 indexed blockedNonce, uint64 blockedAt, uint8 receiptVersion, address originator, address recipient, address recoveryAuthority, address caller, uint256 amount);Fields
token: Addressreceiver: AddressblockedNonce: u64blockedAt: u64receiptVersion: u8originator: Addressrecipient: AddressrecoveryAuthority: Addresscaller: Addressamount: Uint<256, 4>Trait Implementations
Sourceimpl Clone for ReceiptBurned
impl Clone for ReceiptBurned
Sourcefn clone(&self) -> ReceiptBurned
fn clone(&self) -> ReceiptBurned
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
source. Read moreSourceimpl Debug for ReceiptBurned
impl Debug for ReceiptBurned
Sourceimpl<'de> Deserialize<'de> for ReceiptBurned
impl<'de> Deserialize<'de> for ReceiptBurned
Sourcefn deserialize<__D>(
__deserializer: __D,
) -> Result<ReceiptBurned, <__D as Deserializer<'de>>::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(
__deserializer: __D,
) -> Result<ReceiptBurned, <__D as Deserializer<'de>>::Error>where
__D: Deserializer<'de>,
impl Eq for ReceiptBurned
Sourceimpl IntoLogData for ReceiptBurned
impl IntoLogData for ReceiptBurned
Sourcefn to_log_data(&self) -> LogData
fn to_log_data(&self) -> LogData
LogData] object.Sourcefn into_log_data(self) -> LogData
fn into_log_data(self) -> LogData
LogData] object.Sourceimpl JsonAbiExt for ReceiptBurned
impl JsonAbiExt for ReceiptBurned
Sourceimpl PartialEq for ReceiptBurned
impl PartialEq for ReceiptBurned
Sourcefn eq(&self, other: &ReceiptBurned) -> bool
fn eq(&self, other: &ReceiptBurned) -> bool
self and other values to be equal, and is used by ==.Sourceimpl Serialize for ReceiptBurned
impl Serialize for ReceiptBurned
Sourcefn serialize<__S>(
&self,
__serializer: __S,
) -> Result<<__S as Serializer>::Ok, <__S as Serializer>::Error>where
__S: Serializer,
fn serialize<__S>(
&self,
__serializer: __S,
) -> Result<<__S as Serializer>::Ok, <__S as Serializer>::Error>where
__S: Serializer,
Sourceimpl SolEvent for ReceiptBurned
impl SolEvent for ReceiptBurned
Sourceconst SIGNATURE: &'static str = "ReceiptBurned(address,address,uint64,uint64,uint8,address,address,address,address,uint256)"
const SIGNATURE: &'static str = "ReceiptBurned(address,address,uint64,uint64,uint8,address,address,address,address,uint256)"
Sourceconst SIGNATURE_HASH: FixedBytes<32>
const SIGNATURE_HASH: FixedBytes<32>
keccak256(SIGNATURE) Read moreSourcetype DataTuple<'a> = (Uint<64>, Uint<8>, Address, Address, Address, Address, Uint<256>)
type DataTuple<'a> = (Uint<64>, Uint<8>, Address, Address, Address, Address, Uint<256>)
Sourcetype DataToken<'a> = <<ReceiptBurned as SolEvent>::DataTuple<'a> as SolType>::Token<'a>
type DataToken<'a> = <<ReceiptBurned as SolEvent>::DataTuple<'a> as SolType>::Token<'a>
TokenSeq] type corresponding to the tuple.Sourcetype TopicList = (FixedBytes<32>, Address, Address, Uint<64>)
type TopicList = (FixedBytes<32>, Address, Address, Uint<64>)
Sourcefn new(
topics: <<ReceiptBurned as SolEvent>::TopicList as SolType>::RustType,
data: <<ReceiptBurned as SolEvent>::DataTuple<'_> as SolType>::RustType,
) -> ReceiptBurned
fn new( topics: <<ReceiptBurned as SolEvent>::TopicList as SolType>::RustType, data: <<ReceiptBurned as SolEvent>::DataTuple<'_> as SolType>::RustType, ) -> ReceiptBurned
Sourcefn check_signature(
topics: &<<ReceiptBurned as SolEvent>::TopicList as SolType>::RustType,
) -> Result<(), Error>
fn check_signature( topics: &<<ReceiptBurned as SolEvent>::TopicList as SolType>::RustType, ) -> Result<(), Error>
Sourcefn tokenize_body(&self) -> <ReceiptBurned as SolEvent>::DataToken<'_>
fn tokenize_body(&self) -> <ReceiptBurned as SolEvent>::DataToken<'_>
Sourcefn topics(
&self,
) -> <<ReceiptBurned as SolEvent>::TopicList as SolType>::RustType
fn topics( &self, ) -> <<ReceiptBurned as SolEvent>::TopicList as SolType>::RustType
Sourcefn encode_topics_raw(&self, out: &mut [WordToken]) -> Result<(), Error>
fn encode_topics_raw(&self, out: &mut [WordToken]) -> Result<(), Error>
fn new_checked(
topics: <Self::TopicList as SolType>::RustType,
data: <Self::DataTuple<'_> as SolType>::RustType,
) -> Result<Self, Error>
fn new_checked( topics: <Self::TopicList as SolType>::RustType, data: <Self::DataTuple<'_> as SolType>::RustType, ) -> Result<Self, Error>
fn abi_encoded_size(&self) -> usize
fn abi_encoded_size(&self) -> usize
fn encode_data_to(&self, out: &mut Vec<u8>)
fn encode_data_to(&self, out: &mut Vec<u8>)
fn encode_data(&self) -> Vec<u8> ⓘ
fn encode_data(&self) -> Vec<u8> ⓘ
fn encode_topics(&self) -> Vec<WordToken>
fn encode_topics(&self) -> Vec<WordToken>
fn encode_topics_array<const LEN: usize>(&self) -> [WordToken; LEN]
fn encode_topics_array<const LEN: usize>(&self) -> [WordToken; LEN]
fn encode_log_data(&self) -> LogData
fn encode_log_data(&self) -> LogData
LogData].fn encode_log(log: &Log<Self>) -> Log
fn encode_log(log: &Log<Self>) -> Log
Log] containing this event into a [Log] containing
[LogData].fn decode_topics<I, D>(
topics: I,
) -> Result<<Self::TopicList as SolType>::RustType, Error>where
I: IntoIterator<Item = D>,
D: Into<WordToken>,
fn decode_topics<I, D>(
topics: I,
) -> Result<<Self::TopicList as SolType>::RustType, Error>where
I: IntoIterator<Item = D>,
D: Into<WordToken>,
fn abi_decode_data<'a>(
data: &'a [u8],
) -> Result<<Self::DataTuple<'a> as SolType>::RustType, Error>
fn abi_decode_data<'a>( data: &'a [u8], ) -> Result<<Self::DataTuple<'a> as SolType>::RustType, Error>
fn abi_decode_data_validate<'a>(
data: &'a [u8],
) -> Result<<Self::DataTuple<'a> as SolType>::RustType, Error>
fn abi_decode_data_validate<'a>( data: &'a [u8], ) -> Result<<Self::DataTuple<'a> as SolType>::RustType, Error>
fn decode_raw_log<I, D>(topics: I, data: &[u8]) -> Result<Self, Error>where
I: IntoIterator<Item = D>,
D: Into<WordToken>,
fn decode_raw_log<I, D>(topics: I, data: &[u8]) -> Result<Self, Error>where
I: IntoIterator<Item = D>,
D: Into<WordToken>,
fn decode_raw_log_validate<I, D>(topics: I, data: &[u8]) -> Result<Self, Error>where
I: IntoIterator<Item = D>,
D: Into<WordToken>,
fn decode_raw_log_validate<I, D>(topics: I, data: &[u8]) -> Result<Self, Error>where
I: IntoIterator<Item = D>,
D: Into<WordToken>,
fn decode_log_data(log: &LogData) -> Result<Self, Error>
fn decode_log_data(log: &LogData) -> Result<Self, Error>
fn decode_log_data_validate(log: &LogData) -> Result<Self, Error>
fn decode_log_data_validate(log: &LogData) -> Result<Self, Error>
fn decode_log(log: &Log) -> Result<Log<Self>, Error>
fn decode_log(log: &Log) -> Result<Log<Self>, Error>
fn decode_log_validate(log: &Log) -> Result<Log<Self>, Error>
fn decode_log_validate(log: &Log) -> Result<Log<Self>, Error>
impl StructuralPartialEq for ReceiptBurned